@@ -162,7 +162,7 @@ class Container:
                     )
             return params
 
-        def check_equivalent(dep: DependantProtocol[Any]):
+        def check_equivalent(dep: DependantProtocol[Any]) -> None:
             if dep in dep_registry and dep.scope != dep_registry[dep].scope:
                 raise DependencyRegistryError(
                     f"The dependencies {dep} and {dep_registry[dep]}"
@@ -279,7 +279,7 @@ class Container:
     ) -> Tuple[
         Dict[DependantProtocol[Any], Any],
         List[ExecutorTask],
-        typing.List[DependantProtocol[Any]],
+        typing.Iterable[DependantProtocol[Any]],
     ]:
         user_values = values or {}
         if validate_scopes:
@@ -297,7 +297,7 @@ class Container:
             cache.update(mapping)
         cache.update(user_values)
 
-        to_cache: typing.List[DependantProtocol[Any]] = []
+        to_cache: typing.Deque[DependantProtocol[Any]] = deque()
         execution_scope = self.scopes[-1]
 
         results: Dict[DependantProtocol[Any], Any] = {}
@@ -377,7 +377,10 @@ class Container:
 
         return (
             results,
-            [functools.partial(t.compute, state) for t in execution_plan.leaf_tasks],
+            [
+                functools.partial(t.compute, state)  # type: ignore[arg-type]
+                for t in execution_plan.leaf_tasks
+            ],
             to_cache,
         )
 
@@ -424,7 +427,7 @@ class Container:
 
             res = results[solved.dependency]
             self._update_cache(results, to_cache)
-            return res
+            return res  # type: ignore[no-any-return]
 
     async def execute_async(
         self,
@@ -456,4 +459,4 @@ class Container:
                 await executor.execute_async(queue)
             res = results[solved.dependency]
             self._update_cache(results, to_cache)
-            return res
+            return res  # type: ignore[no-any-return]
